@@ -13,7 +13,7 @@ use xCAT::MsgUtils;
 use xCAT::LparNetbootExp;
 
 ##########################################################################
-# Parse the command line for options and operands 
+# Parse the command line for options and operands
 ##########################################################################
 sub parse_args {
 
@@ -27,56 +27,56 @@ sub parse_args {
     #############################################
     local *usage = sub {
         my $usage_string = xCAT::Usage->getUsage($cmd);
-        return( [ $_[0], $usage_string] );
+        return ([ $_[0], $usage_string ]);
     };
     #############################################
     # Process command-line arguments
     #############################################
-    if ( !defined( $args )) {
+    if (!defined($args)) {
         $request->{method} = $cmd;
-        return( \%opt );
+        return (\%opt);
     }
     #############################################
     # Checks case in GetOptions, allows opts
     # to be grouped (e.g. -vx), and terminates
     # at the first unrecognized option.
     #############################################
-    @ARGV = @$args;
+    @ARGV                     = @$args;
     $Getopt::Long::ignorecase = 0;
-    Getopt::Long::Configure( "bundling" );
+    Getopt::Long::Configure("bundling");
 
-    if ( !GetOptions( \%opt, qw(h|help V T v|version I|iscsiboot F f o s=s m:s@ r=s t=s) )) { 
-        return( usage() );
+    if (!GetOptions(\%opt, qw(h|help V T v|version I|iscsiboot F f o s=s m:s@ r=s t=s))) {
+        return (usage());
     }
 
     ####################################
     # Option -h for Help
     ####################################
-    if ( exists( $opt{h} )) {
-        return( usage() );
+    if (exists($opt{h})) {
+        return (usage());
     }
     ####################################
     # Option -v for version
     ####################################
-    if ( exists( $opt{v} )) {
+    if (exists($opt{v})) {
         my $version = xCAT::Utils->Version();
         return ([$version]);
     }
 
-    if ( exists( $opt{s} ) ){
+    if (exists($opt{s})) {
         my @boot_devices = split(/,/, $opt{s});
         foreach (@boot_devices) {
-            if ( (!/^net$/) && (!/^hd$/) ) {
-                return(usage( "boot device $_ is not supported" ));
+            if ((!/^net$/) && (!/^hd$/)) {
+                return (usage("boot device $_ is not supported"));
             }
-         }
+        }
     }
 
-    if (exists( $opt{m} ) ){
+    if (exists($opt{m})) {
         my $res = xCAT::Utils->check_deployment_monitoring_settings($request, \%opt);
         if ($res != SUCCESS) {
-             return(usage());
-        } 
+            return (usage());
+        }
     }
     #############################################
     # T is used for trace, V is used for debug
@@ -85,30 +85,30 @@ sub parse_args {
         $opt{V} = 1;
         delete $opt{T};
 
-    }elsif(exists($opt{V})) {
+    } elsif (exists($opt{V})) {
         $opt{T} = 1;
         delete $opt{V};
     }
     ####################################
     # Check for "-" with no option
     ####################################
-    if ( grep(/^-$/, @ARGV )) {
-        return(usage( "Missing option: -" ));
+    if (grep(/^-$/, @ARGV)) {
+        return (usage("Missing option: -"));
     }
 
     ####################################
     # Check for an extra argument
     ####################################
-    if ( defined( $ARGV[0] )) {
-        return(usage( "Invalid Argument: $ARGV[0]" ));
+    if (defined($ARGV[0])) {
+        return (usage("Invalid Argument: $ARGV[0]"));
     }
-    $request->{method} = $cmd; 
-    return( \%opt );
+    $request->{method} = $cmd;
+    return (\%opt);
 }
 
 
 ##########################################################################
-# Netboot the lpar 
+# Netboot the lpar
 ##########################################################################
 sub do_rnetboot {
 
@@ -130,10 +130,10 @@ sub do_rnetboot {
     #######################################
     # Disconnect Expect session
     #######################################
-    xCAT::PPCcli::disconnect( $exp );
- 
+    xCAT::PPCcli::disconnect($exp);
+
     #######################################
-    # Get node data 
+    # Get node data
     #######################################
     my $id       = @$d[0];
     my $pprofile = @$d[1];
@@ -158,7 +158,7 @@ sub do_rnetboot {
     #######################################
     # Save user name and passwd of hcp to
     # environment variables.
-    # lpar_netboot.expect depends on it 
+    # lpar_netboot.expect depends on it
     #######################################
     $ENV{HCP_USERID} = $userid;
     $ENV{HCP_PASSWD} = $pw;
@@ -166,51 +166,59 @@ sub do_rnetboot {
     #######################################
     # Turn on verbose and debugging
     #######################################
-    if ( ${$request->{arg}}[0] eq '-V' ) {
+    if (${ $request->{arg} }[0] eq '-V') {
+
         #$cmd.= " -v -x";
-        $optarg{'v'} = 1; #for verbose
-        $optarg{'x'} = 1; #for debug
+        $optarg{'v'} = 1;    #for verbose
+        $optarg{'x'} = 1;    #for debug
     }
     #######################################
     # Force LPAR shutdown
     #######################################
-    if ( exists( $opt->{f} ) || !xCAT::Utils->isAIX() ) {
+    if (exists($opt->{f}) || !xCAT::Utils->isAIX()) {
+
         #$cmd.= " -i";
         $optarg{'i'} = 1;
-    } 
+    }
 
     #######################################
     # Write boot order
     #######################################
-    if (  exists( $opt->{s} )) {
+    if (exists($opt->{s})) {
         foreach ($opt->{s}) {
-            if ( /^net$/ ) {
+            if (/^net$/) {
+
                 #$cmd.= " -w 1";
                 $optarg{'w'} = 1;
-            } elsif ( /^net,hd$/ ) {
+            } elsif (/^net,hd$/) {
+
                 #$cmd.= " -w 2";
                 $optarg{'w'} = 2;
-            } elsif ( /^hd,net$/ ) {
+            } elsif (/^hd,net$/) {
+
                 #$cmd.= " -w 3";
                 $optarg{'w'} = 3;
-            } elsif ( /^hd$/ ) {
+            } elsif (/^hd$/) {
+
                 #$cmd.= " -w 4";
                 $optarg{'w'} = 4;
             }
         }
     }
 
-    if (  exists( $opt->{o} )) {
+    if (exists($opt->{o})) {
+
         #$cmd.= " -o";
         $optarg{'o'} = 1;
     }
 
     my @macs = split /\|/, $opt->{m};
-    foreach my $mac ( @macs ) {
+    foreach my $mac (@macs) {
         #######################################
         # Network specified
         #######################################
         my $mac_a = lc($mac);
+
         #$cmd.= " -s auto -d auto -m $mac_a -S $opt->{S} -C $opt->{C} -N $opt->{N}";
 
         $optarg{'s'} = 'auto';
@@ -224,14 +232,14 @@ sub do_rnetboot {
             #$cmd.= " -G $opt->{G}";
             $optarg{'G'} = $opt->{G};
         }
-  
+
 
         #######################################
         # Get required attributes from master
         # of the node if -I|--iscsiboot is
         # specified
         #######################################
-        if (  exists( $opt->{I} )) {
+        if (exists($opt->{I})) {
             my $ret;
             my $dump_target;
             my $dump_lun;
@@ -240,19 +248,19 @@ sub do_rnetboot {
             unless ($noderestab)
             {
                 xCAT::MsgUtils->message('S',
-                                "Unable to open noderes table.\n");
+                    "Unable to open noderes table.\n");
                 return 1;
             }
             my $et = $noderestab->getNodeAttribs($node, ['xcatmaster']);
             if ($et and $et->{'xcatmaster'})
             {
                 $ret = xCAT::Utils->runxcmd(
-                {
-                    command => ['xdsh'],
-                    node    => [$et->{'xcatmaster'}],
-                    arg     => [ 'cat /tftpboot/$node.info' ]
-                },
-                $subreq, 0, 0 );
+                    {
+                        command => ['xdsh'],
+                        node    => [ $et->{'xcatmaster'} ],
+                        arg     => ['cat /tftpboot/$node.info']
+                    },
+                    $subreq, 0, 0);
             } else {
                 $ret = `cat /tftpboot/$node.info`;
             }
@@ -266,24 +274,27 @@ sub do_rnetboot {
                     $dump_lun = $1;
                     $dump_lun =~ s/^0x(.*)$/$1/g;
                 } elsif (/DUMP_PORT=(.*)$/) {
-                    $dump_port =$1;
+                    $dump_port = $1;
                 }
             }
-            if ( defined($dump_target) and defined($dump_lun) and defined($dump_port) ) {
+            if (defined($dump_target) and defined($dump_lun) and defined($dump_port)) {
+
                 #$cmd.= " -T \"$dump_target\" -L \"$dump_lun\" -p \"$dump_port\"";
                 $optarg{'T'} = $dump_target;
                 $optarg{'L'} = $dump_lun;
                 $optarg{'p'} = $dump_port;
             } else {
-                return( [RC_ERROR,"Unable to find DUMP_TARGET, DUMP_LUN, DUMP_PORT for iscsi dump"] );
+                return ([ RC_ERROR, "Unable to find DUMP_TARGET, DUMP_LUN, DUMP_PORT for iscsi dump" ]);
             }
         }
 
-        my %client_nethash = xCAT::DBobjUtils->getNetwkInfo( [$node] );
-        if ( grep /hf/, $client_nethash{$node}{mgtifname} ) {
+        my %client_nethash = xCAT::DBobjUtils->getNetwkInfo([$node]);
+        if (grep /hf/, $client_nethash{$node}{mgtifname}) {
+
             #$cmd.= " -t hfi-ent";
             $optarg{'t'} = "hfi-ent";
         } else {
+
             #$cmd.= " -t ent";
             $optarg{'t'} = "ent";
         }
@@ -292,18 +303,18 @@ sub do_rnetboot {
         # Add command options
         #######################################
         #$cmd.= " -f \"$name\" \"$pprofile\" \"$fsp\" $id $hcp \"$node\"";
-        $optarg{'f'} = 1;
-        $optarg{'name'} = $name;
+        $optarg{'f'}        = 1;
+        $optarg{'name'}     = $name;
         $optarg{'pprofile'} = $pprofile;
-        $optarg{'fsp'} = $fsp;
-        $optarg{'id'} = $id;
-        $optarg{'hcp'} = $hcp;
-        $optarg{'node'} = $node;
+        $optarg{'fsp'}      = $fsp;
+        $optarg{'id'}       = $id;
+        $optarg{'hcp'}      = $hcp;
+        $optarg{'node'}     = $node;
 
         my $done = 0;
-        while ( $done < 2 ) {
+        while ($done < 2) {
             $result = "";
-            $Rc = SUCCESS;
+            $Rc     = SUCCESS;
             ########################################
             ## Execute command
             ########################################
@@ -339,14 +350,14 @@ sub do_rnetboot {
             #######################################
             $result = xCAT::LparNetbootExp->lparnetbootexp(\%optarg, $request);
             $Rc = @$result[0];
-            if ( $Rc == SUCCESS ) {
+            if ($Rc == SUCCESS) {
                 $done = 2;
             } else {
                 $done = $done + 1;
                 sleep 1;
             }
         }
-        if ( $Rc == SUCCESS ) {
+        if ($Rc == SUCCESS) {
             last;
         }
     }
@@ -358,9 +369,10 @@ sub do_rnetboot {
         my $server = @$exp[3];
 
         # creat connection first
-        my @newexp = xCAT::PPCcli::connect( $request, $hwtype, $server );
-        if (ref($newexp[0]) eq "Expect" ) {
+        my @newexp = xCAT::PPCcli::connect($request, $hwtype, $server);
+        if (ref($newexp[0]) eq "Expect") {
             my $cfg = "lpar_id=@$d[0],boot_mode=norm";
+
             # change the boot mode to 'norm'
             xCAT::PPCcli::chsyscfg(\@newexp, "prof", $d, $cfg);
             xCAT::PPCcli::disconnect(\@newexp);
@@ -371,7 +383,7 @@ sub do_rnetboot {
         }
     }
 
-    return  $result;
+    return $result;
 }
 
 
@@ -389,17 +401,17 @@ sub rnetboot {
     my $name;
     my $callback = $request->{callback};
     #####################################
-    # Get node data 
+    # Get node data
     #####################################
     my $lparid = @$d[0];
     my $mtms   = @$d[2];
     my $type   = @$d[4];
     my $node   = @$d[6];
-    my $o      = @$d[7]; 
+    my $o      = @$d[7];
 
     #####################################
-    # Gateway (-G) 
-    # Server  (-S) 
+    # Gateway (-G)
+    # Server  (-S)
     # Client  (-C)
     # mac     (-m)
     #####################################
@@ -413,58 +425,58 @@ sub rnetboot {
 
 
     #####################################
-    # Strip colons from mac address 
+    # Strip colons from mac address
     #####################################
     $opt{m} =~ s/://g;
 
     #####################################
-    # Force LPAR shutdown 
+    # Force LPAR shutdown
     #####################################
-    if ( exists( $options->{f} )) { 
+    if (exists($options->{f})) {
         $opt{f} = 1;
     }
     #####################################
     # Write boot device order
     #####################################
-    if ( exists( $options->{s} )) {
+    if (exists($options->{s})) {
         $opt{s} = $options->{s};
     }
-    
-    if ( exists( $options->{o} )) {
+
+    if (exists($options->{o})) {
         $opt{o} = $options->{o};
     }
 
     #####################################
     # Do iscsi boot
     #####################################
-    if ( exists( $options->{I} )) {
-        $opt{I} = 1; 
+    if (exists($options->{I})) {
+        $opt{I} = 1;
     }
 
     #####################################
-    # Invalid target hardware 
+    # Invalid target hardware
     #####################################
-    if ( $type !~ /^lpar$/ ) {
-        return( [[$name,"Not supported",RC_ERROR]] );
+    if ($type !~ /^lpar$/) {
+        return ([ [ $name, "Not supported", RC_ERROR ] ]);
     }
     #########################################
     # Get name known by HCP
     #########################################
     my $filter = "name,lpar_id";
-    my $values = xCAT::PPCcli::lssyscfg( $exp, $type, $mtms, $filter );
-    my $Rc = shift(@$values);
+    my $values = xCAT::PPCcli::lssyscfg($exp, $type, $mtms, $filter);
+    my $Rc     = shift(@$values);
 
     #########################################
     # Return error
     #########################################
-    if ( $Rc != SUCCESS ) {
-        return( [[$node,@$values[0],$Rc]] );
+    if ($Rc != SUCCESS) {
+        return ([ [ $node, @$values[0], $Rc ] ]);
     }
     #########################################
     # Find LPARs by lpar_id
     #########################################
-    foreach ( @$values ) {
-        if ( /^(.*),$lparid$/ ) {
+    foreach (@$values) {
+        if (/^(.*),$lparid$/) {
             $name = $1;
             last;
         }
@@ -472,8 +484,8 @@ sub rnetboot {
     #########################################
     # Node not found by lpar_id
     #########################################
-    if ( !defined( $name )) {
-        return( [[$node,"Node not found, lparid=$lparid",RC_ERROR]] );
+    if (!defined($name)) {
+        return ([ [ $node, "Node not found, lparid=$lparid", RC_ERROR ] ]);
     }
 
     #########################################
@@ -481,79 +493,82 @@ sub rnetboot {
     # It is not allowed to rinitialize node
     # if it is in boot state
     #########################################
-    if ( !exists( $options->{F} ) && !xCAT::Utils->isAIX() ) {
+    if (!exists($options->{F}) && !xCAT::Utils->isAIX()) {
         my $chaintab = xCAT::Table->new('chain');
-        my $vcon = $chaintab->getAttribs({ node => "$node"}, 'currstate');
-        if ( $vcon and $vcon->{"currstate"} and $vcon->{"currstate"} eq "boot" ) {
-            return( [[$node,"Node is in boot state. Use nodeset command before rnetboot or use -F option with rnetboot",RC_ERROR]] );
+        my $vcon = $chaintab->getAttribs({ node => "$node" }, 'currstate');
+        if ($vcon and $vcon->{"currstate"} and $vcon->{"currstate"} eq "boot") {
+            return ([ [ $node, "Node is in boot state. Use nodeset command before rnetboot or use -F option with rnetboot", RC_ERROR ] ]);
         }
     }
 
     #my $sitetab  = xCAT::Table->new('site');
     #my $vcon = $sitetab->getAttribs({key => "conserverondemand"}, 'value');
     my @vcons = xCAT::TableUtils->get_site_attribute("conserverondemand");
-    my $vcon = $vcons[0]; 
+    my $vcon  = $vcons[0];
+
     #if ($vcon and $vcon->{"value"} and $vcon->{"value"} eq "yes" ) {
-    if ( defined($vcon) and $vcon eq "yes" ) {
+    if (defined($vcon) and $vcon eq "yes") {
         $result = xCAT::PPCcli::lpar_netboot(
-                            $exp,
-                            $request->{verbose},
-                            $name,
-                            $d,
-                            \%opt );
+            $exp,
+            $request->{verbose},
+            $name,
+            $d,
+            \%opt);
     } else {
         #########################################
-        # Manually perform boot. 
+        # Manually perform boot.
         #########################################
-        $result = do_rnetboot( $request, $d, $exp, $name, $node, \%opt );
+        $result = do_rnetboot($request, $d, $exp, $name, $node, \%opt);
     }
+
     #$sitetab->close;
 
     if (defined($request->{opt}->{m})) {
-    
-        my $retries = 0;
+
+        my $retries  = 0;
         my @monnodes = ($name);
         my $monsettings = xCAT::Utils->generate_monsettings($request, \@monnodes);
-        xCAT::Utils->monitor_installation($request, $monsettings);;
-        while ($retries++ < $monsettings->{'retrycount'} && scalar(keys %{$monsettings->{'nodes'}}) > 0) {
+        xCAT::Utils->monitor_installation($request, $monsettings);
+        while ($retries++ < $monsettings->{'retrycount'} && scalar(keys %{ $monsettings->{'nodes'} }) > 0) {
             ####lparnetboot can not support multiple nodes in one invocation
             ####for now, does not know how the $d and \%opt will be changed if
             ####support mulitiple nodes in one invocation,
             ####so just use the original node name and node attribute array and hash
-             
-             my $rsp={};
-             $rsp->{data}->[0] = "$node: Reinitializing the installation: $retries retry";
-             xCAT::MsgUtils->message("I", $rsp, $callback);
-            if ($vcon and $vcon->{"value"} and $vcon->{"value"} eq "yes" ) {
+
+            my $rsp = {};
+            $rsp->{data}->[0] = "$node: Reinitializing the installation: $retries retry";
+            xCAT::MsgUtils->message("I", $rsp, $callback);
+            if ($vcon and $vcon->{"value"} and $vcon->{"value"} eq "yes") {
                 $result = xCAT::PPCcli::lpar_netboot(
-                                    $exp,
-                                    $request->{verbose},
-                                    $name,
-                                    $d,
-                                    \%opt );
+                    $exp,
+                    $request->{verbose},
+                    $name,
+                    $d,
+                    \%opt);
             } else {
-                $result = do_rnetboot( $request, $d, $exp, $name, $node, \%opt );
+                $result = do_rnetboot($request, $d, $exp, $name, $node, \%opt);
             }
             xCAT::Utils->monitor_installation($request, $monsettings);
-                
+
         }
+
         #failed after retries
-        if (scalar(keys %{$monsettings->{'nodes'}}) > 0) {
-            foreach my $node (keys %{$monsettings->{'nodes'}}) {
-                my $rsp={};
+        if (scalar(keys %{ $monsettings->{'nodes'} }) > 0) {
+            foreach my $node (keys %{ $monsettings->{'nodes'} }) {
+                my $rsp = {};
                 $rsp->{data}->[0] = "The node \"$node\" can not reach the expected status after $monsettings->{'retrycount'} retries, the installation for this done failed";
                 xCAT::MsgUtils->message("E", $rsp, $callback);
             }
-         }
+        }
     }
     $Rc = shift(@$result);
-    
+
 
     ##################################
     # Form string from array results
     ##################################
-    if ( exists($request->{verbose}) ) {
-        return( [[$node,join( '', @$result ),$Rc]] );
+    if (exists($request->{verbose})) {
+        return ([ [ $node, join('', @$result), $Rc ] ]);
     }
     ##################################
     # Return error
@@ -569,18 +584,18 @@ sub rnetboot {
     #    lpar_netboot: can not find mac address 42DAB.
     #
     ##################################
-    if ( $Rc != SUCCESS ) {
-        if ( @$result[0] =~ /lpar_netboot (.*)/ ) {
-            return( [[$node,$1,$Rc]] );
+    if ($Rc != SUCCESS) {
+        if (@$result[0] =~ /lpar_netboot (.*)/) {
+            return ([ [ $node, $1, $Rc ] ]);
         }
-        return( [[$node,join( '', @$result ),$Rc]] );
+        return ([ [ $node, join('', @$result), $Rc ] ]);
     }
     ##################################
     # Split array into string
     ##################################
     my $data = @$result[0];
-    if ( $hwtype eq "hmc" ) {
-        $data = join( '', @$result );
+    if ($hwtype eq "hmc") {
+        $data = join('', @$result);
     }
     ##################################
     # lpar_netboot returns:
@@ -595,8 +610,13 @@ sub rnetboot {
     #  # Finished.
     #
     #####################################
-    if ( $data =~ /Finished/) {
-        return( [[$node,"Success",$Rc]] );
+    if ($data =~ /Finished/) {
+        my $newstat       = $::STATUS_POWERING_ON;
+        my %newnodestatus = ();
+        $newnodestatus{$newstat} = [$node];
+        require xCAT_monitoring::monitorctrl;
+        xCAT_monitoring::monitorctrl::setNodeStatusAttributes(\%newnodestatus, 1);
+        return ([ [ $node, "Success", $Rc ] ]);
     }
     #####################################
     # Can still be error w/ Rc=0:
@@ -610,12 +630,12 @@ sub rnetboot {
     #  lpar_netboot: bootp operation failed.
     #
     #####################################
-    if ( $data =~ /lpar_netboot (.*)/ ) {
-        return( [[$node,$1,RC_ERROR]] );
+    if ($data =~ /lpar_netboot (.*)/) {
+        return ([ [ $node, $1, RC_ERROR ] ]);
     }
-    return( [[$node,$data,RC_ERROR]] );
+    return ([ [ $node, $data, RC_ERROR ] ]);
 }
- 
+
 
 1;
 
